diff --git a/webui/static/script.js b/webui/static/script.js
index a9090e85..84998221 100644
--- a/webui/static/script.js
+++ b/webui/static/script.js
@@ -33380,8 +33380,8 @@ function getModalActionButtons(urlHash, phase, state = null) {
let buttons = '';
- // Only show sync button if there are Spotify matches
- if (hasSpotifyMatches) {
+ // Only show sync button if there are Spotify matches (and not standalone mode)
+ if (hasSpotifyMatches && !_isSoulsyncStandalone) {
if (isListenBrainz) {
buttons += ``;
} else if (isTidal) {
@@ -33517,8 +33517,8 @@ function getModalActionButtons(urlHash, phase, state = null) {
case 'sync_complete':
let syncCompleteButtons = '';
- // Only show sync button if there are Spotify matches
- if (hasSpotifyMatches) {
+ // Only show sync button if there are Spotify matches (and not standalone mode)
+ if (hasSpotifyMatches && !_isSoulsyncStandalone) {
if (isListenBrainz) {
syncCompleteButtons += ``;
} else if (isTidal) {